==> flutter_yfree-2.1.0.tar.gz: example/lib/MyPage.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_yfree/YFree.dart';
import 'package:flutter_yfree_example/Localizations.dart';

class MyPage extends YPage {
  var title = "";

  @override
  void yOnCreate() {
    setState(() => title = yGetAppName());
    yShowBuilder("本项目仅可用于学习使用，非作者本人同意，请勿传播或用做任何商业用途。\n感谢您的支持！", () => showToast(), null, false);
    yBroadcast_register("broadcastKey", (params) => yToast(params!["msg"]));
  }

  Future<void> showToast() async {
    yBroadcast_send("broadcastKey", params: {"msg": "欢迎使用YFree_Flutter"});
  }

  Widget view_button(String title, Function() onTap) {
    return YButton(
      child: Text(title, style: const TextStyle(color: Colors.white, fontSize: 20, fontWeight: FontWeight.bold)),
      padding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
      color: YConfig.themeColor,
      onTap: onTap,
    );
  }

  @override
  Widget yBuild(BuildContext context) {
    return Container(
      color: Colors.white,
      child: Column(
        children: <Widget>[
          YAppBar(title: title, canBack: false),
          Container(
            width: yScreenSize(context).width,
            padding: const EdgeInsets.all(5),
            child: Wrap(
              spacing: 5,
              runSpacing: 5,
              children: [
                view_button("模拟广播".yLocale(), () => showToast()),
                YSpacer(height: 10),
                view_button("切换语言".yLocale(), () {
                  final items = [null, zh, en];
                  yShowSelectBuilder("切换语言".yLocale(), true, items.map((e) => getLanguage(e)).toList(), (index, action) {
                    YLocaleUtils.updateAppLocale(items[index]);
                  });
                }),
              ],
            ),
          ),
        ],
      ),
    );
  }
}

==> flutter_yfree-2.1.6.tar.gz: example/lib/MyPage.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_yfree/YFree.dart';
import 'package:flutter_yfree_example/Localizations.dart';

class MyPage extends YPage {
  var title = "";

  @override
  void yOnCreate() {
    setState(() => title = yGetAppName());
    yShowBuilder("本项目仅可用于学习使用，非作者本人同意，请勿传播或用做任何商业用途。\n感谢您的支持！", () => showToast(), null, false);
    yBroadcast_register("broadcastKey", (params) => yToast(params!["msg"]));
  }

  Future<void> showToast() async {
    yBroadcast_send("broadcastKey", params: {"msg": "欢迎使用YFree_Flutter"});
  }

  Widget view_button(String title, Function() onTap) {
    return YButton(
      child: Text(title, style: const TextStyle(color: Colors.white, fontSize: 20, fontWeight: FontWeight.bold)),
      padding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
      color: YConfig.themeColor,
      onTap: onTap,
    );
  }

  @override
  Widget yBuild(BuildContext context) {
    return Container(
      color: Colors.white,
      child: Column(
        children: <Widget>[
          YAppBar(title: title, canBack: false),
          Container(
            width: yScreenSize().width,
            padding: const EdgeInsets.all(5),
            child: Wrap(
              spacing: 5,
              runSpacing: 5,
              children: [
                view_button("模拟广播".yLocale(), () => showToast()),
                YSpacer(height: 10),
                view_button("切换语言".yLocale(), () {
                  final items = [null, zh, en];
                  yShowSelectBuilder("切换语言".yLocale(), true, items.map((e) => getLanguage(e)).toList(), (index, action) {
                    YLocaleUtils.updateAppLocale(items[index]);
                  });
                }),
              ],
            ),
          ),
        ],
      ),
    );
  }
}
